==> ppd-cli-test-1.0.6.tgz: package/lib/index.js <==
"use strict";

const path = require("path");
const semver = require("semver");
const colors = require("colors/safe");
const userHome = require("user-home");
const pathExists = require("path-exists").sync;
const commander = require("commander");
const pkg = require("../package.json");
console.log("🚀 ~ pkg", pkg);

const log = require("../utils/log/index.js");
console.log(log, "===log");
const exec = require("../models/exec");

const constant = require("./const");

const program = new commander.Command();

async function core() {
  console.log(111111);
  // try {
  //   await prepare();
  //   registerCommand();
  // } catch (e) {
  //   log.error(e.message);
  //   if (program.debug) {
  //     console.log(e);
  //   }
  // }
}

async function prepare() {
  checkPkgVersion();
  checkRoot();
  checkUserHome();
  checkEnv();
  await checkGlobalUpdate();
}

// 检查版本是否需要全局更新
async function checkGlobalUpdate() {
  // 1.获取当前版本号
  const currentVersion = pkg.version;
  const npmName = pkg.name;
  // 2.调用npm API,获取所有的版本号
  const { getNmpSemverVersion } = require("../utils/get-npm-info");
  const newVersion = await getNmpSemverVersion(currentVersion, npmName);
  // console.log(newVersion, "===data");
  // 3.提取所有版本号,对比那些版本号大于当前版本号
  // 4.获取最新版本号,提示用户更新到该版本
  if (newVersion && semver.gt(newVersion, currentVersion)) {
    log.warn(
      `更新提示:`,
      colors.yellow(
        `请手动更新到${newVersion},当前版本:${currentVersion},最新版本:${newVersion} 更新命令: npm install -g ${npmName}`
      )
    );
  }
}

// 配置环境变量
function checkEnv() {
  // 加载环境变量配置
  const dotenv = require("dotenv");
  const dotenvPath = path.resolve(userHome, ".env");
  // 本地目录Users/chenhuan/.env有环境变量
  if (pathExists(dotenvPath)) {
    // 加载环境变量从.env中
    dotenv.config({
      path: dotenvPath,
    });
  }
  createDefaultConfig();
}

function createDefaultConfig() {
  const cliConfig = {
    home: userHome,
  };
  console.log(process.env.CLI_HOME_PPD_DEV, "===process.env.CLI_HOME_PPD_DEV");
  if (process.env.CLI_HOME_PPD_DEV) {
    cliConfig["cliHome"] = path.join(userHome, process.env.CLI_HOME_PPD_DEV);
  } else {
    cliConfig["cliHome"] = path.join(userHome, constant.DEFAULT_CLI_HOME);
  }
  process.env.CLI_HOME_PATH = cliConfig.cliHome;
}

// 判断用户主目录,没有用户主目录 缓存这些都做不了
function checkUserHome() {
  // pathExists 当前文件是否存在
  if (!userHome || !pathExists(userHome)) {
    throw new Error(colors.red(`当前用户主目录不存在`));
  }
}

// 检查root启动
// root创建文件的话 就是root账户, 普通用户没法修改, 甚至有读写权限的话 各种权限会报错
function checkRoot() {
  // console.log(process.geteuid()); // sudu 0
  // root-check 检查是否是sudo启动, 降级权限
  const rootCheck = require("root-check");
  rootCheck();
}

function checkPkgVersion() {
  log.notice("cli", pkg.version);
}

function registerCommand() {
  program
    .name(Object.keys(pkg.bin)[0])
    .usage("<command> [options]")
    .version(pkg.version)
    .option("-d, --debug", "是否开启调试模式", false)
    .option("-tp, --targetPath <path>", "是否指定本地调试文件路径", "");

  program
    .command("init [projectName]")
    .description("创建一个新项目")
    .option("-f, --force", "是否强制创建项目")
    .action(exec);

  program.on("option:debug", function (value) {
    if (program.debug) {
      process.env.LOG_LEVELE = "verbose";
    } else {
      process.env.LOG_LEVELE = "info";
    }
    log.level = process.env.LOG_LEVELE;
  });

  program.on("option:targetPath", function () {
    if (program.targetPath) {
      process.env.CLI_TARGET_PATH = program.targetPath;
    }
  });

  program.on("command:*", function (command) {
    log.error(`命令 ${command} 不存在`);
    const availableCommands = program.commands.map((cmd) => cmd.name);
    if (availableCommands.length > 0) {
      console.log(`可用命令: ${availableCommands.join(", ")}`);
    }
  });

  program.parse(process.argv);

  if (program.args && program.args.length < 1) {
    program.outputHelp();
    console.log();
  }
}

module.exports = core;

==> ppd-cli-test-1.0.10.tgz: package/lib/index.js <==
"use strict";

const path = require("path");
const semver = require("semver");
const colors = require("colors/safe");
const userHome = require("user-home");
const pathExists = require("path-exists").sync;
const commander = require("commander");
const pkg = require("../package.json");
const log = require("../utils/log");
const exec = require("../models/exec");
const constant = require("./const");

const program = new commander.Command();

async function core() {
  try {
    await prepare();
    registerCommand();
  } catch (e) {
    log.error(e.message);
    if (program.debug) {
      console.log(e);
    }
  }
}

async function prepare() {
  checkPkgVersion();
  checkRoot();
  checkUserHome();
  checkEnv();
  await checkGlobalUpdate();
}

// 检查版本是否需要全局更新
async function checkGlobalUpdate() {
  // 1.获取当前版本号
  const currentVersion = pkg.version;
  const npmName = pkg.name;
  // 2.调用npm API,获取所有的版本号
  const { getNmpSemverVersion } = require("../utils/get-npm-info");
  const newVersion = await getNmpSemverVersion(currentVersion, npmName);
  // console.log(newVersion, "===data");
  // 3.提取所有版本号,对比那些版本号大于当前版本号
  // 4.获取最新版本号,提示用户更新到该版本
  if (newVersion && semver.gt(newVersion, currentVersion)) {
    log.warn(
      `更新提示:`,
      colors.yellow(
        `请手动更新到${newVersion},当前版本:${currentVersion},最新版本:${newVersion} 更新命令: npm install -g ${npmName}`
      )
    );
  }
}

// 配置环境变量
function checkEnv() {
  // 加载环境变量配置
  const dotenv = require("dotenv");
  const dotenvPath = path.resolve(userHome, ".env");
  // 本地目录Users/chenhuan/.env有环境变量
  if (pathExists(dotenvPath)) {
    // 加载环境变量从.env中
    dotenv.config({
      path: dotenvPath,
    });
  }
  createDefaultConfig();
}

function createDefaultConfig() {
  const cliConfig = {
    home: userHome,
  };
  console.log(process.env.CLI_HOME_PPD_DEV, "===process.env.CLI_HOME_PPD_DEV");
  if (process.env.CLI_HOME_PPD_DEV) {
    cliConfig["cliHome"] = path.join(userHome, process.env.CLI_HOME_PPD_DEV);
  } else {
    cliConfig["cliHome"] = path.join(userHome, constant.DEFAULT_CLI_HOME);
  }
  process.env.CLI_HOME_PATH = cliConfig.cliHome;
}

// 判断用户主目录,没有用户主目录 缓存这些都做不了
function checkUserHome() {
  // pathExists 当前文件是否存在
  if (!userHome || !pathExists(userHome)) {
    throw new Error(colors.red(`当前用户主目录不存在`));
  }
}

// 检查root启动
// root创建文件的话 就是root账户, 普通用户没法修改, 甚至有读写权限的话 各种权限会报错
function checkRoot() {
  // console.log(process.geteuid()); // sudu 0
  // root-check 检查是否是sudo启动, 降级权限
  const rootCheck = require("root-check");
  rootCheck();
}

function checkPkgVersion() {
  log.notice("cli", pkg.version);
}

function registerCommand() {
  program
    .name(Object.keys(pkg.bin)[0])
    .usage("<command> [options]")
    .version(pkg.version)
    .option("-d, --debug", "是否开启调试模式", false)
    .option("-tp, --targetPath <path>", "是否指定本地调试文件路径", "");

  program
    .command("init [projectName]")
    .description("创建一个新项目")
    .option("-f, --force", "是否强制创建项目")
    .action(exec);

  program.on("option:debug", function (value) {
    if (program.debug) {
      process.env.LOG_LEVELE = "verbose";
    } else {
      process.env.LOG_LEVELE = "info";
    }
    log.level = process.env.LOG_LEVELE;
  });

  program.on("option:targetPath", function () {
    if (program.targetPath) {
      process.env.CLI_TARGET_PATH = program.targetPath;
    }
  });

  program.on("command:*", function (command) {
    log.error(`命令 ${command} 不存在`);
    const availableCommands = program.commands.map((cmd) => cmd.name);
    if (availableCommands.length > 0) {
      console.log(`可用命令: ${availableCommands.join(", ")}`);
    }
  });

  program.parse(process.argv);

  if (program.args && program.args.length < 1) {
    program.outputHelp();
    console.log();
  }
}

module.exports = core;
